.. _pipelines:

Search Chaining
===============

**Search Chaining** break the lens modeling procedure down into a series of linked model-fits, providing
automated and efficient fits to the most complex lens models

The readthedocs overview for **Search Chaining** is not written yet. However, checkout
`Chapter 3 of the HowToLens lectures <https://pyautolens.readthedocs.io/en/latest/howtolens/chapter_3_pipelines/index.html>`_
for a complete description.